package code.model

import java.sql.Date
import scala.slick.driver.H2Driver.simple._
import scala.slick.collection.heterogenous._
import syntax._

class RoyaltyDatabase {
  // Map database "y" and "n" values to a proper boolean type
  val YesNoMapper = MappedColumnType.base[Boolean, String](if(_) "y" else "n", _=="y")
 
  case class Administrator(
      id: Int,
      name: String,
      street1: Option[String],
      street2: Option[String],
      city: Option[String],
      state: Option[String],
      zip: Option[String],
      phone: Option[String],
      email: Option[String]
  )
  
  class Administrators(tag: Tag) extends Table[Administrator](tag, "administrator") {
    def id = column[Int]("id", O.PrimaryKey, O.AutoInc, O.DBType("int(10) unsigned"))
    def name = column[String]("name", O.DBType("VARCHAR(255)")) // UNIQUE KEY
    def street1 = column[Option[String]]("street1", O.DBType("VARCHAR(255)"))
    def street2 = column[Option[String]]("street2", O.DBType("VARCHAR(255)"))
    def city = column[Option[String]]("city", O.DBType("VARCHAR(127)"))
    def state = column[Option[String]]("state", O.DBType("VARCHAR(5)"))
    def zip = column[Option[String]]("zip", O.DBType("VARCHAR(10)"))
    def phone = column[Option[String]]("phone", O.DBType("VARCHAR(16)"))
    def email = column[Option[String]]("email", O.DBType("VARCHAR(127)"))
    def * = (id, name, street1, street2, city, state, zip, phone, email) <> (Administrator.tupled, Administrator.unapply)
  }
  val administrators = TableQuery[Administrators]


  class ThirtyTwoCols(tag: Tag) extends Table[
      Int :: Option[Int] :: Option[String] :: String :: Option[Date] ::
      Option[Int] :: Int :: Boolean :: Boolean :: Option[Double] ::
      Boolean :: Option[BigDecimal] :: Option[Double] :: Option[Double] :: Boolean ::
      Option[Double] :: Option[Double] :: Boolean :: Option[Double] :: Boolean ::
      Option[Int] :: Option[Double] :: Float :: Float :: Float ::
      Boolean :: Boolean :: Option[Short] :: Option[String] :: Option[String] ::
      Boolean :: Boolean :: Option[Double]  :: HNil ](tag, "thirty_two") {
    def int1 = column[Int]("id", O.PrimaryKey, O.AutoInc, O.DBType("int(11)"))
    def option_int2 = column[Option[Int]]("col2", O.DBType("int(11)")) // KEY
    def option_string3 = column[Option[String]]("col3", O.DBType("VARCHAR(255)")) // UNIQUE KEY
    def string4 = column[String]("col4", O.DBType("VARCHAR(255)"), O.Default(""))
    def option_date5 = column[Option[Date]]("col5", O.DBType("date"))

    def option_int6 = column[Option[Int]]("col6", O.DBType("int(11)"))
    def int7 = column[Int]("col7", O.DBType("int(11)"), O.Default(1))
    def boolean8 = column[Boolean]("col8", O.Default(true),O.DBType("enum('y','n')"))(YesNoMapper)
    def boolean9 = column[Boolean]("col9", O.Default(true),O.DBType("enum('y','n')"))(YesNoMapper) // nullable in schema
    def option_double10 = column[Option[Double]]("col10", O.DBType("double"))
    
    def boolean11 = column[Boolean]("col11", O.Default(true),O.DBType("enum('y','n')"))(YesNoMapper)
    def option_bigdecimal12 = column[Option[BigDecimal]]("col12", O.DBType("decimal(10, 2)"))
    def option_double13 = column[Option[Double]]("col13", O.DBType("double"))
    def option_bigdecimal14 = column[Option[BigDecimal]]("col14", O.DBType("decimal(10, 2)"))
    def boolean15 = column[Boolean]("col15", O.Default(false),O.DBType("enum('y','n')"))(YesNoMapper)
    
    def option_double16 = column[Option[Double]]("col16", O.DBType("double"))
    def option_double17 = column[Option[Double]]("col17", O.DBType("double"))
    def boolean18 = column[Boolean]("col18", O.Default(false),O.DBType("enum('y','n')"))(YesNoMapper)
    def option_double19 = column[Option[Double]]("col19", O.DBType("double"))
    def boolean20 = column[Boolean]("col20", O.Default(true),O.DBType("enum('y','n')"))(YesNoMapper)
    
    def option_int21 = column[Option[Int]]("col21")
    def option_double22 = column[Option[Double]]("col22")
    def float23 = column[Float]("col23", O.Default(0))
    def float24 = column[Float]("col24", O.Default(0))
    def float25 = column[Float]("col25", O.Default(0))
  
    def boolean26 = column[Boolean]("col26", O.Default(false),O.DBType("enum('y','n')"))(YesNoMapper)
    def boolean27 = column[Boolean]("col27", O.Default(false))(YesNoMapper)
    def option_short28 = column[Option[Short]]("col28", O.DBType("int(16) unsigned"))
    def option_string29 = column[Option[String]]("col29", O.DBType("VARCHAR(10,2)"))
    def option_string30 = column[Option[String]]("col30", O.DBType("VARCHAR(10,2)"))
    def boolean31 = column[Boolean]("col31", O.Default(true),O.DBType("enum('y','n')"))(YesNoMapper)
    def boolean32 = column[Boolean]("col32", O.Default(true),O.DBType("enum('y','n')"))(YesNoMapper)
  
  }
  val thirty_two = TableQuery[ThirtyTwoCols]


}

